HTML Pandas Dataframe with CSS

## Mismatches in Table : ILMASTAccount2_2010

## Data only in SQL but not in RedShift

| ilmastaccount2key | ildw_term | ildw_unearn_term | ildw_ntd_10_29 | ildw_ntd_30_59 | ildw_ntd_60_89 | ildw_partial_pay_amt | ildw_m_last_tran_amt | ildw_no_extns | ildw_bill_day | ildw_cur_78_factor | ildw_nxt_78_factor | ildw_m_ytd_int_pd_prior | ildw_m_assd_lchrgs | ildw_m_ytd_lchrgs | ildw_unpaid_lchrgs_amt | ildw_paid_lchrgs | ildw_m_misc_fees_assd | ildw_m_misc_fees_pd | ildw_m_misc_fees_unpd | ildw_no_mos_run | ildw_m_no_mos_run_ytd | ildw_m_no_nsf | ildw_m_assd_oth_chrg | ildw_paid_oth_chrg | ildw_unpaid_oth_chrg | ildw_m_over_pymnt | ildw_ps28_no_pmt_1 | ildw_ps28_sched_2 | ildw_ps28_no_pmt_2 | ildw_ps28_amt_2 | ildw_no_pmt1 | ildw_m_cur_unearn_bk | ildw_int_earned_ltd | ildw_m_uf_num72_1 | ildw_key | ildw_mat_dte | ildw_chg_off_cd | ildw_late_chg_code | ildw_hold_code | ildw_clos | ildw_m_last_tran | ildw_est_mat_date | ildw_m_misc_code2 | ildw_m_misc_status | ildw_notice | ildw_ps28_strt_dt_1 | ildw_polk_model_yr | ildw_polk_make | ildw_polk_model | ildw_m_cs_application_score | ildw_m_uf_alpha1_2 | ildw_m_uf_alpha4_2 | ildw_m_cs_override_code | ildw_m_cs_cutoff_score | ildw_m_user_remarks | ildw_m_cs_bypass_code | ildw_m_accounting_unit | ildw_m_acb_charge_off_amt | ildw_m_acb_close_pd_days | ildw_na_cons_info_ind | ildw_co_na_cons_info_ind | ildw_m_acb_high_balance | ildw_m_payoff_trans | ildw_m_uf_num7_2 | scdstartdate | scdenddate | islatest | firstinserted | lastupdated | insertetlid | updateetlid | etllogid | ildw_m_tick_a_cd | ildw_m_clctn_off | ildw_m_uf_alpha1_4 | ildw_m_uf_alpha1_5 | ildw_m_uf_alpha1_6 | ildw_m_uf_alpha1_9
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

## Data only in RedShift but not in SQL

| ilmastaccount2key | ildw_term | ildw_unearn_term | ildw_ntd_10_29 | ildw_ntd_30_59 | ildw_ntd_60_89 | ildw_partial_pay_amt | ildw_m_last_tran_amt | ildw_no_extns | ildw_bill_day | ildw_cur_78_factor | ildw_nxt_78_factor | ildw_m_ytd_int_pd_prior | ildw_m_assd_lchrgs | ildw_m_ytd_lchrgs | ildw_unpaid_lchrgs_amt | ildw_paid_lchrgs | ildw_m_misc_fees_assd | ildw_m_misc_fees_pd | ildw_m_misc_fees_unpd | ildw_no_mos_run | ildw_m_no_mos_run_ytd | ildw_m_no_nsf | ildw_m_assd_oth_chrg | ildw_paid_oth_chrg | ildw_unpaid_oth_chrg | ildw_m_over_pymnt | ildw_ps28_no_pmt_1 | ildw_ps28_sched_2 | ildw_ps28_no_pmt_2 | ildw_ps28_amt_2 | ildw_no_pmt1 | ildw_m_cur_unearn_bk | ildw_int_earned_ltd | ildw_m_uf_num72_1 | ildw_key | ildw_mat_dte | ildw_chg_off_cd | ildw_late_chg_code | ildw_hold_code | ildw_clos | ildw_m_last_tran | ildw_est_mat_date | ildw_m_misc_code2 | ildw_m_misc_status | ildw_notice | ildw_ps28_strt_dt_1 | ildw_polk_model_yr | ildw_polk_make | ildw_polk_model | ildw_m_cs_application_score | ildw_m_uf_alpha1_2 | ildw_m_uf_alpha4_2 | ildw_m_cs_override_code | ildw_m_cs_cutoff_score | ildw_m_user_remarks | ildw_m_cs_bypass_code | ildw_m_accounting_unit | ildw_m_acb_charge_off_amt | ildw_m_acb_close_pd_days | ildw_na_cons_info_ind | ildw_co_na_cons_info_ind | ildw_m_acb_high_balance | ildw_m_payoff_trans | ildw_m_uf_num7_2 | scdstartdate | scdenddate | islatest | firstinserted | lastupdated | insertetlid | updateetlid | etllogid | ildw_m_tick_a_cd | ildw_m_clctn_off | ildw_m_uf_alpha1_4 | ildw_m_uf_alpha1_5 | ildw_m_uf_alpha1_6 | ildw_m_uf_alpha1_9
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

.